@@ -23,7 +23,7 @@ import util
 __all__ = []
 __author__ = "Wei Zhuo <zeaphoo@gmail.com>"
 __license__ = "MIT"
-__version__ = ".".join(map(str, (0, 3, 1)))
+__version__ = ".".join(map(str, (0, 3, 2)))
 
 SERVER_SOFTWARE = "grunner/%s" % __version__
 
@@ -199,7 +199,7 @@ class GeventRunner(object):
         self.log.info("Starting grunner %s", __version__)
         self.init_signals()
         if not self.LISTENERS:
-            self.LISTENERS.append(_tcp_listener(self.address))
+            self.LISTENERS.append(_tcp_listener(self.address), reuse_addr = 1)
         self.log.info("Listening at: %s:%d (%s)", self.address[0], self.address[1], self.pid)
 
     def init_signals(self):
